@@ -825,22 +825,25 @@ def make(io):
     model = ANN((1,1), (1, 1), "sigmoid")
         
     #essential imports
+    
+    try:
+        model.input_shape = model_json["input_shape"]
+        model.structure = model_json["structure"]
+        model.strict = model_json["strict"]
+        model.initializer = model_json["initializer"]
+        model.output = model_json["output"]
+        model.loss = model_json["loss"]
+        model.activations = model_json["activations"]
+        model.delta = model_json["delta"]
         
-    model.input_shape = model_json["input_shape"]
-    model.structure = model_json["structure"]
-    model.strict = model_json["strict"]
-    model.initializer = model_json["initializer"]
-    model.output = model_json["output"]
-    model.loss = model_json["loss"]
-    model.activations = model_json["activations"]
-    model.delta = model_json["delta"]
+        temp = []
+        for i in range(len(model.structure)):
+            temp.append(np.array(model_json["w_layers"][i]))
         
-    temp = []
-    for i in range(len(model.structure)):
-        temp.append(np.array(model_json["w_layers"][i]))
-        
-    model.w_layers = temp
-    model.b_layers = model_json["b_layers"]
+        model.w_layers = temp
+        model.b_layers = model_json["b_layers"]
+    except Exception as e:
+        pass
         
         
     #optional import
